<?php

namespace Drupal\tacjs\Form\Steps;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ManageDialog.
 *
 * @package Drupal\tacjs\Form
 */
class ManageDialog extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tacjs_manage_dialog';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tacjs.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $form['privacyUrl'] = [
      '#type' => 'textfield',
      '#title' => t('Privacy url'),
      '#description' => t('Privacy policy url'),
      '#default_value' => $config->get('dialog.privacyUrl'),
    ];

    $form['cookieName'] = [
      '#type' => 'textfield',
      '#title' => t('Cookie name'),
      '#default_value' => $config->get('dialog.cookieName'),
    ];

    $form['hashtag'] = [
      '#type' => 'textfield',
      '#title' => t('Hashtag'),
      '#description' => t('Open the panel with this hashtag'),
      '#default_value' => $config->get('dialog.hashtag'),
    ];

    $form['orientation'] = [
      '#type' => 'radios',
      '#title' => t('Orientation'),
      '#description' => t('Banner position (top - bottom)'),
      '#default_value' => $config->get('dialog.orientation'),
      '#options' => [
        'top' => t('Top'),
        'middle' =>  t('Middle'),
        'bottom' => t('Bottom'),
      ],
    ];

    $form['showAlertSmall'] = [
      '#type' => 'checkbox',
      '#title' => t('Show alert small'),
      '#description' => t('Show the small banner on bottom right'),
      '#default_value' => $config->get('dialog.showAlertSmall'),
    ];

    $form['cookieslist'] = [
      '#type' => 'checkbox',
      '#title' => t('Cookies list'),
      '#description' => t('Show the cookie list'),
      '#default_value' => $config->get('dialog.cookieslist'),
    ];

    $form['adblocker'] = [
      '#type' => 'checkbox',
      '#title' => t('Adblocker'),
      '#description' => t('Show a Warning if an adblocker is detected'),
      '#default_value' => $config->get('dialog.adblocker'),
    ];

    $form['AcceptAllCta'] = [
      '#type' => 'checkbox',
      '#title' => t('Accept all cta'),
      '#description' => t('Show the accept all button when high privacy on'),
      '#default_value' => $config->get('dialog.AcceptAllCta'),
    ];

    $form['highPrivacy'] = [
      '#type' => 'checkbox',
      '#title' => t('High privacy'),
      '#description' => t('Disable auto consent'),
      '#default_value' => $config->get('dialog.highPrivacy'),
    ];

    $form['handleBrowserDNTRequest'] = [
      '#type' => 'checkbox',
      '#title' => t('Handle browser DNT request'),
      '#description' => t('If Do Not Track == 1, disallow all'),
      '#default_value' => $config->get('dialog.handleBrowserDNTRequest'),
    ];

    $form['removeCredit'] = [
      '#type' => 'checkbox',
      '#title' => t('Remove credit'),
      '#description' => t('Remove credit link'),
      '#default_value' => $config->get('dialog.removeCredit'),
    ];

    $form['moreInfoLink'] = [
      '#type' => 'checkbox',
      '#title' => t('More info link'),
      '#description' => t('Show more info link'),
      '#default_value' => $config->get('dialog.moreInfoLink'),
    ];

    $form['useExternalCss'] = [
      '#type' => 'checkbox',
      '#title' => t('Use external CSS'),
      '#default_value' => $config->get('dialog.useExternalCss'),
    ];

    $form['cookieDomain'] = [
      '#type' => 'textarea',
      '#title' => t('Cookie domain'),
      '#description' => t('Shared cookie for subdomain website'),
      '#default_value' => $config->get('dialog.cookieDomain'),
    ];

    $form['readmoreLink'] = [
      '#type' => 'textfield',
      '#title' => t('Read more link'),
      '#description' => t('Change the default readmore link pointing to opt-out.ferank.eu'),
      '#default_value' => $config->get('dialog.readmoreLink'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $form_state
      ->setValue('showAlertSmall', $form_state->getValue('showAlertSmall') ? TRUE : FALSE)
      ->setValue('cookieslist', $form_state->getValue('cookieslist') ? TRUE : FALSE)
      ->setValue('adblocker', $form_state->getValue('adblocker') ? TRUE : FALSE)
      ->setValue('AcceptAllCta', $form_state->getValue('AcceptAllCta') ? TRUE : FALSE)
      ->setValue('highPrivacy', $form_state->getValue('highPrivacy') ? TRUE : FALSE)
      ->setValue('handleBrowserDNTRequest', $form_state->getValue('handleBrowserDNTRequest') ? TRUE : FALSE)
      ->setValue('removeCredit', $form_state->getValue('removeCredit') ? TRUE : FALSE)
      ->setValue('moreInfoLink', $form_state->getValue('moreInfoLink') ? TRUE : FALSE)
      ->setValue('useExternalCss', $form_state->getValue('useExternalCss') ? TRUE : FALSE);

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $config
      ->set('dialog.privacyUrl', $form_state->getValue('privacyUrl'))
      ->set('dialog.hashtag', $form_state->getValue('hashtag'))
      ->set('dialog.cookieName', $form_state->getValue('cookieName'))
      ->set('dialog.orientation', $form_state->getValue('orientation'))
      ->set('dialog.showAlertSmall', $form_state->getValue('showAlertSmall'))
      ->set('dialog.cookieslist', $form_state->getValue('cookieslist'))
      ->set('dialog.adblocker', $form_state->getValue('adblocker'))
      ->set('dialog.AcceptAllCta', $form_state->getValue('AcceptAllCta'))
      ->set('dialog.highPrivacy', $form_state->getValue('highPrivacy'))
      ->set('dialog.handleBrowserDNTRequest', $form_state->getValue('handleBrowserDNTRequest'))
      ->set('dialog.removeCredit', $form_state->getValue('removeCredit'))
      ->set('dialog.moreInfoLink', $form_state->getValue('moreInfoLink'))
      ->set('dialog.useExternalCss', $form_state->getValue('useExternalCss'))
      ->set('dialog.cookieDomain', $form_state->getValue('cookieDomain'))
      ->set('dialog.readmoreLink', $form_state->getValue('readmoreLink'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
